@@ -1,11 +1,11 @@
-# circuitpython_dfrobot_gravity_drf0627_dual_uart: Copyright (c) 2022 Graham Beland
+# circuitpython_dfrobot_gravity_drf0627_dual_uart: Copyright (c) 2022 Graham N Beland
 #
 # SPDX-License-Identifier: MIT
 
 """
-`circuitpython_dfrobot_gravity_drf0627_dual_uart`
+circuitpython_dfrobot_gravity_drf0627_dual_uart
 ================================================================================
-* Author(s): Graham Beland, Sept. 2022
+Author(s): Graham Beland, Sept. 2022
 Implementation Notes
 --------------------
 **Hardware:**
@@ -29,13 +29,13 @@ Implementation Notes
  @copyright   Copyright (c) 2010 DFRobot Co.Ltd (http://www.dfrobot.com)
  @license     The MIT License (MIT)
  @author [Arya](xue.peng@dfrobot.com)
- @version  V1.0
+ @version  V1.1
  @date  2021-05-07
  @https://github.com/DFRobot/DFRobot_IIC_Serial
 """
 # imports
 
-__version__ = "1.0.13"
+__version__ = "1.0.14"
 __repo__ = (
     "https://github.com/gbeland/CircuitPython_DFRobot_Gravity_DRF0627_I2C_Dual_Uart.git"
 )
@@ -44,8 +44,10 @@ __repo__ = (
 import time
 import array as arr
 
+
 class DFRobot_IIC_Serial:
     """DFRobot_IIC_Serial"""
+
     # Global control register, control sub UART clock
     REG_WK2132_GENA = 0x00
     # Global sub UART reset register, reset a sub UART independently through software
@@ -381,7 +383,7 @@ class DFRobot_IIC_Serial:
             databyte = bytes(value, "ascii")
         elif isinstance(value, int):
             # print("int detected")
-            databyte = arr.array('b', bytearray([value % 0xFF]))
+            databyte = arr.array("b", bytearray([value % 0xFF]))
         else:
             databyte = value
 
